@@ -26,6 +26,13 @@ import org.gnu.pango.FontDescription;
 
 /**
  * VteTerminal widget bindings implementation.
+ *
+ * @deprecated This class is part of the java-gnome 2.x family of libraries,
+ *             which, due to their inefficiency and complexity, are no longer
+ *             being maintained and have been abandoned by the java-gnome
+ *             project. This class may have an equivalent
+ *             in java-gnome 4.0; have a look for
+ *             <code>org.gnome.vte.Terminal</code>.
  */
 public class Terminal extends org.gnu.gtk.Widget {
 	
@@ -33,31 +40,55 @@ public class Terminal extends org.gnu.gtk.Widget {
 	
     /**
      * Listeners for handling generic terminal events.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     private Vector terminalListeners = null;
 
     /**
      * Listeners for handling terminal commit events.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     private Vector commitListeners = null;
 
     /**
      * Listeners for handling terminal character size change events.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     private Vector characterSizeChangeListeners = null;
 
     /**
      * Listeners for handling terminal move window events.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     private Vector moveWindowListeners = null;
 
     /**
      * Listeners for handling terminal resize window events.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     private Vector resizeWindowListeners = null;
 
     /**
      * Listeners for handling terminal text scrolled events.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     private Vector textScrolledListeners = null;
     
@@ -263,6 +294,10 @@ public class Terminal extends org.gnu.gtk.Widget {
 			throw new FileNotFoundException();
 	}
 		
+    public void setBackgroudImage(String file) throws FileNotFoundException{
+	setBackgroundImage(file);
+    }
+
 	/**
 	 * Sets the background image for the widget.  Text which would otherwise 
 	 * be drawn using the default background color will instead be drawn 
@@ -321,6 +356,10 @@ public class Terminal extends org.gnu.gtk.Widget {
 		vte_terminal_set_color_background(getHandle(), color.getHandle());
 	}	
 
+    public void setBackgroudColor(Color color) {
+	setBackgroundColor(color);
+    }
+
 	/**
 	 * Sets the foreground color used to draw normal text
 	 * @param color
@@ -495,6 +534,10 @@ public class Terminal extends org.gnu.gtk.Widget {
     /**
      * Get the {@link Adjustment} which is the "model" object for Terminal.
      * @return The adjustment model
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     public Adjustment getAdjustment() {
         Handle hndl = vte_terminal_get_adjustment(getHandle());
@@ -870,6 +913,10 @@ public class Terminal extends org.gnu.gtk.Widget {
      * Called when the command executed through vte_terminal_fork_command is
      * no longer running.
      * This method will automatically fire a TerminalEvent.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     private void handleChildExited() {
         fireTerminalEvent(new TerminalEvent(this, TerminalEvent.Type.CHILD_EXITED));
@@ -878,6 +925,10 @@ public class Terminal extends org.gnu.gtk.Widget {
     /**
      * Called when the Terminal has it's selection changed.
      * This method will automatically fire a TerminalEvent.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     private void handleSelectionChanged() {
         fireTerminalEvent(new TerminalEvent(this, TerminalEvent.Type.SELECTION_CHANGED));
@@ -888,6 +939,10 @@ public class Terminal extends org.gnu.gtk.Widget {
      * This method will automatically fire a TerminalCommitEvent.
      * @param text the text that's being commited.
      * @param length the length of the text recieved.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     private void handleCommit(String text, int length) {
         
@@ -905,6 +960,10 @@ public class Terminal extends org.gnu.gtk.Widget {
      * This method will automatically fire a TerminalCharacterSizeChangedEvent.
      * @param width the new character cell width.
      * @param height the new character cell height. 
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     private void handleCharSizeChanged(int width, int height) {
 
@@ -920,6 +979,10 @@ public class Terminal extends org.gnu.gtk.Widget {
     /**
      * Called whenever the visible appearance of the Terminal have changed.
      * This method will automatically fire a TerminalEvent.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     private void handleContentsChanged() {
         fireTerminalEvent(new TerminalEvent(this, TerminalEvent.Type.CONTENTS_CHANGED));
@@ -928,6 +991,10 @@ public class Terminal extends org.gnu.gtk.Widget {
     /**
      * Called whenever the cursor moves to a new character cell.
      * This method will automatically fire a TerminalEvent.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     private void handleCursorMoved() {
         fireTerminalEvent(new TerminalEvent(this, TerminalEvent.Type.CURSOR_MOVED));
@@ -935,6 +1002,10 @@ public class Terminal extends org.gnu.gtk.Widget {
     
     /**
      * Called when the user hits the '-' key while holding the Control key.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     private void handleDecreaseFontSize() {
         fireTerminalEvent(new TerminalEvent(this, TerminalEvent.Type.DECREASE_FONT_SIZE));
@@ -942,6 +1013,10 @@ public class Terminal extends org.gnu.gtk.Widget {
 
     /**
      * Emitted at the child application's request.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     private void handleDeiconifyWindow() {
         fireTerminalEvent(new TerminalEvent(this, TerminalEvent.Type.DEICONIFY_WINDOW));
@@ -949,6 +1024,10 @@ public class Terminal extends org.gnu.gtk.Widget {
 
     /**
      * Emitted when the terminal emulation changes.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     private void handleEmulationChanged() {
         fireTerminalEvent(new TerminalEvent(this, TerminalEvent.Type.EMULATION_CHANGED));
@@ -956,6 +1035,10 @@ public class Terminal extends org.gnu.gtk.Widget {
 
     /**
      * Emitted when the encoding of the terminal changes.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     private void handleEncodingChanged() {
         fireTerminalEvent(new TerminalEvent(this, TerminalEvent.Type.ENCODING_CHANGED));
@@ -963,6 +1046,10 @@ public class Terminal extends org.gnu.gtk.Widget {
 
     /**
      * Emitted when an End-Of-File is issued to the terminal.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     private void handleEof() {
         fireTerminalEvent(new TerminalEvent(this, TerminalEvent.Type.EOF));
@@ -970,6 +1057,10 @@ public class Terminal extends org.gnu.gtk.Widget {
 
     /**
      * Emitted when the terminal's icon_title field is modified.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     private void handleIconTitleChanged() {
         fireTerminalEvent(new TerminalEvent(this, TerminalEvent.Type.ICON_TITLE_CHANGED));
@@ -977,6 +1068,10 @@ public class Terminal extends org.gnu.gtk.Widget {
 
     /**
      * Emitted at the child application's request.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     private void handleIconifyWindow() {
         fireTerminalEvent(new TerminalEvent(this, TerminalEvent.Type.ICONIFY_WINDOW));
@@ -984,6 +1079,10 @@ public class Terminal extends org.gnu.gtk.Widget {
 
     /**
      * Emitted when the user hits the '+' key while holding the Control key.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     private void handleIncreaseFontSize() {
         fireTerminalEvent(new TerminalEvent(this, TerminalEvent.Type.INCREASE_FONT_SIZE));
@@ -991,6 +1090,10 @@ public class Terminal extends org.gnu.gtk.Widget {
 
     /**
      * Emitted at the child application's request.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     private void handleLowerWindow() {
         fireTerminalEvent(new TerminalEvent(this, TerminalEvent.Type.LOWER_WINDOW));
@@ -998,6 +1101,10 @@ public class Terminal extends org.gnu.gtk.Widget {
 
     /**
      * Emitted at the child application's request.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     private void handleMaximizeWindow() {
         fireTerminalEvent(new TerminalEvent(this, TerminalEvent.Type.MAXIMIZE_WINDOW));
@@ -1007,6 +1114,10 @@ public class Terminal extends org.gnu.gtk.Widget {
      * Emitted at the child application's request.
      * @param x the terminal's desired location, X coordinate.
      * @param y the terminal's desired location, Y coordinate.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     private void handleMoveWindow(int x, int y) {
         MoveWindowEvent event = new MoveWindowEvent(this,
@@ -1017,6 +1128,10 @@ public class Terminal extends org.gnu.gtk.Widget {
 
     /**
      * Emitted at the child application's request.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     private void handleRaiseWindow() {
         fireTerminalEvent(new TerminalEvent(this, TerminalEvent.Type.RAISE_WINDOW));
@@ -1024,6 +1139,10 @@ public class Terminal extends org.gnu.gtk.Widget {
 
     /**
      * Emitted at the child application's request.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     private void handleRefreshWindow() {
         fireTerminalEvent(new TerminalEvent(this, TerminalEvent.Type.REFRESH_WINDOW));
@@ -1033,6 +1152,10 @@ public class Terminal extends org.gnu.gtk.Widget {
      * Emitted at the child application's request.
      * @param width the desired width in pixels.
      * @param height the desired height in pixels.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     private void handleResizeWindow(int width, int height) {
         ResizeWindowEvent event = new ResizeWindowEvent(this,
@@ -1043,6 +1166,10 @@ public class Terminal extends org.gnu.gtk.Widget {
 
     /**
      * Emitted at the child application's request.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     private void handleRestoreWindow() {
         fireTerminalEvent(new TerminalEvent(this, TerminalEvent.Type.RESTORE_WINDOW));
@@ -1050,6 +1177,10 @@ public class Terminal extends org.gnu.gtk.Widget {
 
     /**
      * Emitted whenever the contents of the status line are modified or cleared.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     private void handleStatusLineChanged() {
         fireTerminalEvent(new TerminalEvent(this, TerminalEvent.Type.STATUS_LINE_CHANGED));
@@ -1058,6 +1189,10 @@ public class Terminal extends org.gnu.gtk.Widget {
     /**
      * An internal signal used for communication between the terminal and its accessibility peer. 
      * May not be emitted under certain circumstances.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     private void handleTextDeleted() {
         fireTerminalEvent(new TerminalEvent(this, TerminalEvent.Type.TEXT_DELETED));
@@ -1066,6 +1201,10 @@ public class Terminal extends org.gnu.gtk.Widget {
     /**
      * An internal signal used for communication between the terminal and its accessibility peer. 
      * May not be emitted under certain circumstances.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     private void handleTextInserted() {
         fireTerminalEvent(new TerminalEvent(this, TerminalEvent.Type.TEXT_INSERTED));
@@ -1074,6 +1213,10 @@ public class Terminal extends org.gnu.gtk.Widget {
     /**
      * An internal signal used for communication between the terminal and its accessibility peer. 
      * May not be emitted under certain circumstances.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     private void handleTextModified() {
         fireTerminalEvent(new TerminalEvent(this, TerminalEvent.Type.TEXT_MODIFIED));
@@ -1084,6 +1227,10 @@ public class Terminal extends org.gnu.gtk.Widget {
      * May not be emitted under certain circumstances.
      * @param delta <i>Unknown this field was copied at it is from the <code>C</code> source code 
      * of the vte widget since it's missing from the documentation.</i>
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     private void handleTextScrolled(int delta) {
         TextScrolledEvent event = new TextScrolledEvent(this,
@@ -1094,6 +1241,10 @@ public class Terminal extends org.gnu.gtk.Widget {
 
     /**
      * Emitted when the terminal's window_title field is modified.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     private void handleWindowTitleChanged() {
         fireTerminalEvent(new TerminalEvent(this, TerminalEvent.Type.WINDOW_TITLE_CHANGED));
@@ -1213,6 +1364,10 @@ public class Terminal extends org.gnu.gtk.Widget {
      * Checks if the terminal currently contains selected text. 
      * Note that this is different from determining if the terminal 
      * is the owner of any GtkClipboard items. 
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     static native boolean vte_terminal_get_has_selection(Handle handle);
 
